class App {
  constructor(apps) {
    this.apps = apps;
    this.disabledApps = this.getDisabledApps();
    this.$progressbar = $('.progress-bar');

    this.initHandlers();
    this.setEnabledClass();
    this.setSidebarState();
    this.initSavedIframeView();
  }

  getDisabledApps() {
    const json = localStorage.getItem('disabled_apps') || '[]';
    return JSON.parse(json);
  }

  saveStorage() {
    const json = JSON.stringify(this.disabledApps);
    localStorage.setItem('disabled_apps', json);
  }

  initHandlers() {
    const $b = $(document.body);

    // Adiciona o listener para detectar as teclas pressionadas
    document.addEventListener("keydown", this.onKeyDown.bind(this));

    $b.on('click', '#settings-view .app-item-box',          e => this.appsSetChange(e));
    $b.on('click', '.js-set-active-iframe',                 e => this.setActiveIframeClick(e));
    $b.on('click', '.js-reload-page', () => location.reload());
    $b.on('click', '.js-iframe-page',                       e => this.setReloadIframeClick(e));
    $b.on('click', '.js-welcome-slider-btn:not(.active)', function () {
        $('.js-welcome-slider-btn').toggleClass('active');
        $('#welcome-view').find('.slider-box').toggleClass('second-view');
    });
    $b.on('click', '.js-list-slider-btn:not(.active)', function () {
        $('.js-list-slider-btn').toggleClass('active');
        $('#list-view').find('.slider-box').toggleClass('second-view');
    });
    $b.on('click', '[show-view]', e => {
        const el = e.target.closest('[show-view]');
        const v = el.getAttribute('show-view');
        this.setActiveView(v);
    });
	
	$b.on('click', '.js-home', function () {
        const listView = document.getElementById('list-view');
        if (listView.classList.contains('active')) {
        listView.style.display = 'none';
        listView.classList.remove('active');
    } else {
        listView.style.display = 'block';
        listView.classList.add('active');
    }
    });
	$b.on('click', '.js-settings', function () {
        const listView = document.getElementById('settings-view');
        if (listView.classList.contains('active')) {
        listView.style.display = 'none';
        listView.classList.remove('active');
    } else {
        listView.style.display = 'block';
        listView.classList.add('active');
    }
    });
	$b.on('click', '.js-contact', function () {
        const listView = document.getElementById('welcome-view');
        if (listView.classList.contains('active')) {
        listView.style.display = 'none';
        listView.classList.remove('active');
    } else {
        listView.style.display = 'block';
        listView.classList.add('active');
    }
    });	
    $b.on('click', '.js-hamburger', function () {
        this.classList.toggle('is-active');
        document.body.classList.toggle('active-sidebar');
        localStorage.sidebar_state = localStorage.sidebar_state === 'show' ? 'hide' : 'show';
    });
    $b.on('change', '#switch-version-checkbox', function () {
        localStorage.version = 'old';
        setTimeout(() => { location.pathname = '/start_WCEX/'; }, 500);
    });
  }

onKeyDown(event) {
    if (event.keyCode === 38) {
      window.scrollTo(0, window.pageYOffset - 50);
    } else if (event.keyCode === 40) {
      window.scrollTo(0, window.pageYOffset + 50);
    } 
  }


    setEnabledClass() {
        $('[data-app-url]').each((i, el) => {
            const appId = el.getAttribute('data-app-url');
            const isDisabled = this.disabledApps.includes(appId);
            const a = isDisabled ? 'remove' : 'add';
            el.classList[a]('enabled');
        });
    }

    setSidebarState() {
        if(!localStorage.sidebar_state) localStorage.sidebar_state = 'show';

        if(localStorage.sidebar_state === 'show') {
            $('.js-hamburger').addClass('is-active');
            document.body.classList.add('active-sidebar');
        }
    }

    setActiveView(v) {
        document.getElementById('view-box').setAttribute('data-a-view', v);
    }

    appsSetChange(e) {
        const el = e.target.closest('[data-app-url]');
        const appId = el.getAttribute('data-app-url');
        const index = this.disabledApps.indexOf(appId);

        index > -1 ? this.disabledApps.splice(index, 1) : this.disabledApps.push(appId) ;

        this.saveStorage();
        this.setEnabledClass();
    }


setReloadIframeClick(e) {
    const iframe = document.getElementById('video');
    const iframeWindow = iframe.contentWindow;
	iframeWindow.postMessage('stop', '*');
	iframe.src = iframe.src;
}



closeActiveIframe() {
    const activeIframe = document.querySelector('iframe[data-url].active');
    if (activeIframe) {
      activeIframe.classList.remove('active');
      activeIframe.style.display = 'none';
      activeIframe.remove(); // adicionado
    }
}

  setActiveIframeClick(e) {
    
    const views = document.querySelectorAll('#list-view, #settings-view, #welcome-view');
    views.forEach(view => {
    if (view.classList.contains('active')) {
    view.style.display = 'none';
    view.classList.remove('active');
  }
  });
	this.closeActiveIframe();
    this.highlightActiveApp(e);
    const el = e.target.closest('[data-app-url]');
    const url = el.getAttribute('data-app-url');
    const iframeSrc = this.getIframeSrc(url);
    this.setActiveIframe(iframeSrc);
    localStorage.active_iframe = url;
  }

  setActiveIframe(url) {
    const target = document.querySelector(`iframe[data-url="${url}"]`);
    const iframeError = document.getElementById('iframe-error');
    iframeError.classList.remove('time');

    $('iframe').removeClass('active').hide();

    if(target) {
      target.style.display = 'block';
      target.classList.add('active');
    } else {
      this.$progressbar.show();

      const view   = document.getElementById('iframe-view');
      const iframe = document.createElement('iframe');
      iframe.allowFullscreen = true;
      iframe.style.display= "block"; 
      iframe.id = 'video';
      iframe.style.width = "100%";
      iframe.style.height = "100%";
      iframe.src   = url;
      iframe.innerHTML = 'If WhatsApp does not loaded <a href="https://spaconett.com/Impact/" target="_top">click here, please</a>';
      iframe.setAttribute('data-url', url);
      iframe.onload = () => {
        this.$progressbar.hide();
        iframe.classList.add('active');
      };
      view.appendChild(iframe);

      setTimeout(() => {
      iframeError.classList.add('time');
      this.$progressbar.hide();
      setTimeout(() => {
        iframeError.classList.remove('time');
       }, 10000);
    }, 1500);
    }
  }


    highlightActiveApp(e) {
        const target = e.currentTarget;
        const parent = target.closest('#sidebar');
        const activeApp = parent.querySelector('.app-item.active');
        if (activeApp && activeApp !== target) {
            activeApp.classList.remove('active');
        }
        target.classList.add('active');
    }

    initSavedIframeView() {
        const url = localStorage.active_iframe;
        if(!url) return;

        const iframeSrc = this.getIframeSrc(url);

        this.setActiveIframe(iframeSrc);
        this.setActiveView('iframe-view');
    }

    getIframeSrc(url) {
        return this.canOpenInIframe(url) ? url : '' + decodeURIComponent(url);
    }

    canOpenInIframe(url) {
        const app = this.apps.find(a => a.url === url);
        if(!app) return console.error('app not found');

        return app.iframe;
    }
}

const app = new App(APPS);
